import { DefaultHttpClient } from './http-client';
const baseURL = 'https://scrapbox.io/api';
export const isObject = (data) => typeof data === 'object' && data !== null;
export const isNotLoggedInError = (data) => isObject(data) && data['name'] === 'NotLoggedInError';
export class RestApiClient {
    token;
    httpClient;
    constructor(token, httpClient = new DefaultHttpClient()) {
        this.token = token;
        this.httpClient = httpClient;
    }
    async getPage(projectName, pageName) {
        return this.request(`${baseURL}/pages/${encodeURIComponent(projectName)}/${encodeURIComponent(pageName)}?followRename=true`);
    }
    async getProject(projectName) {
        return this.request(`${baseURL}/projects/${encodeURIComponent(projectName)}`);
    }
    async getMe() {
        return this.request(`${baseURL}/users/me`);
    }
    async request(url) {
        const result = await this.httpClient.get(url, {
            headers: {
                Cookie: `connect.sid=${this.token}`,
            },
        });
        if (isNotLoggedInError(result)) {
            throw new Error('NotLoggedInError');
        }
        return result;
    }
}
//# sourceMappingURL=rest-api-client.js.map